@@ -2,13 +2,11 @@
 
 LEVEL_DIR=/usr/share/games/rocksndiamonds
 
-
 if test -d $LEVEL_DIR/levels; then
 	exec /usr/games/rocksndiamonds-bin "$@"
 else
 	echo "Game data not installed!"
 	echo
-	echo "usage: #dpkg-reconfigure rocksndiamonds"
-	echo "for install/update game levels"
+	echo "Run \`dpkg-reconfigure rocksndiamonds' as root"
+	echo "to install/update game levels."
 fi
-
